from setuptools import setup

with open("README.md", "r") as f:
  long_description = f.read()

setup(
  name='moretypes',
  version='0.0.1',
  description='A Python types extension library that allows for more even versatile data storage and referencing.',
  py_modules=['moretypes'],
  package_dir={"": "src"},
  long_description=long_description,
  long_description_content_type="text/markdown",
  url=None,
  author="minecraftpr03",
  author_email=None,
  classifiers=[
    "Programming Language :: Python :: 3",
    "Programming Language :: Python :: 3.6",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
    "License :: OSI Approved :: MIT License",
    "Operating System :: OS Independent"
  ]
)